@@ -24,6 +24,7 @@ message_output_type = {
     "action_start": "action_event",
     "trigger_start": "trigger_event",
     "task_start": "task_event",
+    "connection_test": "connection_test",
 }
 
 
@@ -312,9 +313,11 @@ class Plugin(object):
                 )
             if not isinstance(body["task"], str):
                 raise ClientException("Task field must be a string")
+        elif type_ == "connection_test":
+            pass
         else:
             raise ClientException(
-                "Unsupported message type %s. Must be action_start, trigger_start or task_start"
+                "Unsupported message type %s. Must be action_start, trigger_start, connection_test, or task_start"
             )
 
         if "meta" not in body:
@@ -361,7 +364,7 @@ class Plugin(object):
             # Attempt to grab message type first
             message_type = input_message.get("type")
             out_type = message_output_type.get(message_type)
-            if message_type not in ["action_start", "trigger_start", "task_start"]:
+            if message_type not in ["action_start", "trigger_start", "task_start", "connection_test"]:
                 raise ClientException(
                     'Unsupported message type "{}"'.format(message_type)
                 )
@@ -410,6 +413,17 @@ class Plugin(object):
                         is_test,
                         is_debug,
                     )
+            elif message_type == "connection_test":
+                out_type = "connection_test"
+                output = self.start_step(
+                    input_message["body"],
+                    "connection_test",
+                    logger,
+                    log_stream,
+                    is_test,
+                    is_debug,
+                    is_connection_test=True
+                )
         except (ClientException, ServerException, PluginException, Exception) as e:
             success = False
             caught_exception = e
@@ -432,7 +446,7 @@ class Plugin(object):
             return output
 
     def start_step(
-            self, message_body, step_key, logger, log_stream, is_test=False, is_debug=False
+            self, message_body, step_key, logger, log_stream, is_test=False, is_debug=False, is_connection_test=False
     ):
         """
         Starts an action.
@@ -444,95 +458,114 @@ class Plugin(object):
         :param is_debug: True if debug is enabled
         :return: An action_event message
         """
-
-        action_name = message_body[step_key]
-        dictionary = getattr(self, step_key + "s")
-        if action_name not in dictionary:
-            raise ClientException('Unknown {} "{}"'.format(step_key, action_name))
-        action = dictionary[action_name]
-
         connection = self.connection_cache.get(message_body["connection"], logger)
-
-        # Copy the action for thread safety.
-        # This is necessary because the object itself contains stateful fields like connection and debug.
-        step = copy.copy(action)
-
-        step.debug = is_debug
-        step.connection = connection
-        step.logger = logger
-
-        # Extra setup for triggers
-        if step_key == "trigger":
-            step.log_stream = log_stream
-            step.meta = message_body["meta"]
-            step.webhook_url = message_body["dispatcher"]["webhook_url"]
-            step.url = message_body["dispatcher"]["url"]
-
-            if not step.dispatcher:
-                if step.debug:
-                    step.dispatcher = Stdout(message_body["dispatcher"])
-                else:
-                    step.dispatcher = Http(message_body["dispatcher"])
-
-        params = message_body["input"]
-        state = {}
-
-        if not is_test:
-            # Validate input message
-            try:
-                step.input.validate(params)
-                if step_key == "task":
-                    state = message_body["state"]
-                    step.state.validate(state)
-
-                # Validate required inputs
-                # Step inputs will be checked against schema for required properties existence
-                # This is needed to prevent null/empty string values from being passed as output to input of steps
-                step.input.validate_required(params)
-            except jsonschema.exceptions.ValidationError as e:
-                raise ClientException("{} input JSON was invalid".format(step_key), e)
-            except Exception as e:
-                raise Exception("Unable to validate {} input JSON".format(step_key), e)
-
-        # Log step information for improved debugging with users
-        step.logger.info(
-            "{vendor}/{plugin_name}:{plugin_version}. Step name: {step_name}".format(
-                vendor=step.connection.meta.vendor,
-                plugin_name=step.connection.meta.name,
-                plugin_version=step.connection.meta.version,
-                step_name=step.name,
+        if is_connection_test:
+            logger.info(
+                "{vendor}/{plugin_name}:{plugin_version}".format(
+                    vendor=connection.meta.vendor,
+                    plugin_name=connection.meta.name,
+                    plugin_version=connection.meta.version,
+                )
             )
-        )
-
-        if is_test:
-            # Check if connection test func available. If so - use it (preferred). Else fallback to action/trigger test
-            if hasattr(step.connection, "test"):
-                func = step.connection.test
+            if hasattr(connection, "test"):
+                func = connection.test
             else:
-                func = step.test
+                raise NotImplementedError(
+                    "The server successfully processed the request and is not "
+                    "returning any content (no connection test function)"
+                )
+            output = func()
+            
+            return output
+
         else:
-            func = step.run
+            action_name = message_body[step_key]
+            dictionary = getattr(self, step_key + "s")
+            if action_name not in dictionary:
+                raise ClientException('Unknown {} "{}"'.format(step_key, action_name))
+            action = dictionary[action_name]
 
-        # Backward compatibility with steps with missing argument params
-        # The SDK has always defined the signature of the run/test methods to include the params dictionary.
-        # However, the code generation generates the test method without the params argument.
-        parameters = inspect.signature(func)
-        if len(parameters.parameters) > 0:
-            if step_key == "task" and not is_test:
-                output, state = func(params, state)
+            # Copy the action for thread safety.
+            # This is necessary because the object itself contains stateful fields like connection and debug.
+            step = copy.copy(action)
+
+            step.debug = is_debug
+            step.connection = connection
+            step.logger = logger
+
+            # Extra setup for triggers
+            if step_key == "trigger":
+                step.log_stream = log_stream
+                step.meta = message_body["meta"]
+                step.webhook_url = message_body["dispatcher"]["webhook_url"]
+                step.url = message_body["dispatcher"]["url"]
+
+                if not step.dispatcher:
+                    if step.debug:
+                        step.dispatcher = Stdout(message_body["dispatcher"])
+                    else:
+                        step.dispatcher = Http(message_body["dispatcher"])
+
+            params = message_body["input"]
+            state = {}
+    
+            if not is_test:
+                # Validate input message
+                try:
+                    step.input.validate(params)
+                    if step_key == "task":
+                        state = message_body["state"]
+                        step.state.validate(state)
+    
+                    # Validate required inputs
+                    # Step inputs will be checked against schema for required properties existence
+                    # This is needed to prevent null/empty string values from being passed as output to input of steps
+                    step.input.validate_required(params)
+                except jsonschema.exceptions.ValidationError as e:
+                    raise ClientException("{} input JSON was invalid".format(step_key), e)
+                except Exception as e:
+                    raise Exception("Unable to validate {} input JSON".format(step_key), e)
+
+            # Log step information for improved debugging with users
+            step.logger.info(
+                "{vendor}/{plugin_name}:{plugin_version}. Step name: {step_name}".format(
+                    vendor=step.connection.meta.vendor,
+                    plugin_name=step.connection.meta.name,
+                    plugin_version=step.connection.meta.version,
+                    step_name=step.name,
+                )
+            )
+        
+            if is_test:
+                # Check if connection test func available. If so - use it (preferred). Else fallback to action/trigger test
+                if hasattr(step.connection, "test"):
+                    func = step.connection.test
+                else:
+                    func = step.test
             else:
-                output = func(params)
-        else:
-            if step_key == "task" and not is_test:
-                output, state = func()
+                func = step.run
+    
+            # Backward compatibility with steps with missing argument params
+            # The SDK has always defined the signature of the run/test methods to include the params dictionary.
+            # However, the code generation generates the test method without the params argument.
+            parameters = inspect.signature(func)
+            if len(parameters.parameters) > 0:
+                if step_key == "task" and not is_test:
+                    output, state = func(params, state)
+                else:
+                    output = func(params)
             else:
-                output = func()
-
-        # Don't validate output for any test functions - action/trigger tests shouldn't be validated due to them
-        # not providing value and a connection test shouldn't be validated due to it being generic/universal
-        if not is_test:
-            step.output.validate(output)
-
-        if step_key == "task" and not is_test:
-            return output, state
-        return output
+                if step_key == "task" and not is_test:
+                    output, state = func()
+                else:
+                    output = func()
+    
+            # Don't validate output for any test functions - action/trigger tests shouldn't be validated due to them
+            # not providing value and a connection test shouldn't be validated due to it being generic/universal
+            if not is_test:
+                step.output.validate(output)
+    
+            if step_key == "task" and not is_test:
+                return output, state
+        
+            return output
